Get the path to an example file shipped with the package.
Source:R/examples.R
fundsr_example_data.RdGet the path to an example file shipped with the package.

R/examples.R
fundsr_example_data.RdGet the path to an example file shipped with the package.