Vendor-specific import wrappers for NAV histories.
Usage
ishs(ticker, file = NULL, benchmark = NULL, retrieve_benchmark = FALSE, ...)
spdr(ticker, file = NULL, benchmark = NULL, ...)
xtra(ticker, file = NULL, benchmark = NULL, retrieve_benchmark = FALSE, ...)
amun(ticker, file = NULL, benchmark = NULL, ...)
inve(ticker, file = NULL, benchmark = NULL, retrieve_benchmark = FALSE, ...)
vang(ticker, file = NULL, benchmark = NULL, ...)
ubs(ticker, file = NULL, benchmark = NULL, ...)
hsbc(ticker, file = NULL, benchmark = NULL, ...)
bnpp(ticker, file = NULL, benchmark = NULL, ...)
avan(ticker, file = NULL, benchmark = NULL, var_name = NULL, ...)Arguments
- ticker
Fund identifier/ticker.
- file
Optional filename. The default is
toupper(ticker)with an extension determined by the vendor format, such as.xls[x]or.csv.- benchmark
Optional benchmark identifier (to be added to the fund-index map).
- retrieve_benchmark
Logical. Also import the vendor-supplied benchmark series. Only supported for NAV histories from Invesco, iShares, and Xtrackers (
inve(),ishs(),xtra()).- ...
Arguments passed on to
store_timeseriesoverwriteLogical scalar. If
TRUE, recompute and replace any existing cached value, regardless offundsr.reload.postprocessFunction applied to the computed value before caching. Only used when the value is (re)computed (i.e. not applied when a cached value is reused). Defaults to
base::identity().sessionOptional
fundsr_sessionobject. Defaults to the package default session whenNULL.
- var_name
Optional custom storage key. Supported by all wrapper functions, either as a formal argument or via
...passed to the underlying helper (import_fund()orstore_timeseries()).
Value
Invisibly returns NULL. Data are stored via store_timeseries().
Details
Most fund importers are wrappers around import_fund() (which uses store_timeseries() and
read_timeseries_excel()). Some use store_timeseries() directly, coupled with a reader like
read_timeseries() or read_timeseries_excel(). Extra arguments (...) are passed to
store_timeseries(). For wrappers built on import_fund(), ... is first passed through
import_fund().
Functions
ishs(): Import an iShares NAV historyspdr(): Import an SPDR NAV historyxtra(): Import an Xtrackers NAV historyamun(): Import an Amundi NAV historyinve(): Import an Invesco NAV historyvang(): Import a Vanguard NAV historyubs(): Import a UBS NAV historyhsbc(): Import an HSBC NAV historybnpp(): Import a BNP Paribas NAV historyavan(): Import an Avantis NAV history
Examples
if (FALSE) { # \dontrun{
xtra("SCWX", benchmark = "ACWI", file = "HistoricalData-LU2903252349.xlsx")
spdr(
"SPYI",
benchmark = "ACWI_IMI",
postprocess = function(x) {
adjust_for_split(x, lubridate::as_date("2026-02-23"), 25, "spyi")
}
)
fs <- fundsr_session()
inve("FWRA", benchmark = "FTAW", retrieve_benchmark = TRUE, session = fs)
} # }